pub type AllPalletsWithoutSystem = (PalletWithExternalOrigin,);Expand description
All pallets included in the runtime as a nested tuple of types. Excludes the System pallet.
pub type AllPalletsWithoutSystem = (PalletWithExternalOrigin,);All pallets included in the runtime as a nested tuple of types. Excludes the System pallet.